@@ -1,4 +1,4 @@
-//  $Id: roe_tcl.cc 1.11 Wed, 10 Jun 1998 15:31:22 -0700 cengiz $
+//  $Id: roe_tcl.cc 1.12 Wed, 09 Jun 1999 10:42:04 -0700 cengiz $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -628,6 +628,8 @@ void roe_initialize_GUI() {
 #endif // LOAD_FILE
    char sources[256];
    strncpy(sources, whois->GetSources(), sizeof(sources));
+   if (! *sources) 
+      strcpy(sources, "radb,ripe,ans,cw,canet");
    for (char *s = strtok(sources, ","); s; s = strtok(NULL, ","))
       tcl_Eval(".menubar.selection.menu.sources add command -label %s -command { roe_del_selected_matching_source [.routes.list curselection] %s}", s, s);
 
