@@ -1,4 +1,4 @@
-//  $Id: schema_rpsl.cc 1.7 Wed, 17 Nov 1999 12:16:46 -0800 fabio $
+//  $Id: schema_rpsl.cc 1.9 Wed, 02 Feb 2000 18:12:52 -0800 cengiz $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -81,7 +81,6 @@ mnt-by: MNT-CENGIZ
 changed: cengiz@isi.edu 19980324
 source: RPS-WG
 typedef: ListOfIPv4Prefix list of Address_Prefix
-typedef: Date integer[19000000,20000000]
 typedef: as_number-as_set_name union as_number, as_set_name
 typedef: ListOfas_number list of as_number
 typedef: ListOfas_number-as_set_name list of as_number-as_set_name
@@ -315,8 +314,6 @@ attr:  admin-c                                                                 m
 
 class: as-block
 attr:  as-block         syntax(union as_number, range of as_number),           mandatory, single,   key
-attr:  country                                                                 mandatory, multiple
-attr:  status                                                                  mandatory, single
 attr:  mnt-lower        syntax(ListOfrpsl_word),                               optional,  multiple                   " CMN_ATTRS "
 attr:  descr                                                                   mandatory, single
 attr:  mnt-by           syntax(list of rpsl_word),                             optional,  multiple, lookup
@@ -352,6 +349,9 @@ attr:  descr                optional,   multiple
 attr:  admin-c              mandatory,  multiple, lookup
 attr:  tech-c               mandatory,  multiple, lookup
 attr:  mnt-by               mandatory,  multiple, lookup " CMN_ATTRS "
+
+class: test
+attr: test syntax(date)
 ";
 
 void Schema::addClass(AttrClass *clss) {
